@@ -11,7 +11,7 @@ from .permissions import CustomerPermissions, ProjectPermissions, ProjectMemberP
 from .views import ProjectMembersViewset
 
 class Customer(Model):
-    name = models.CharField(max_length=255)
+    name = models.CharField(max_length=255, null=True, blank=True)
     address = models.CharField(max_length=255, null=True, blank=True)
     logo = models.URLField(blank=True, null=True)
     companyRegister = models.CharField(max_length=255, null=True, blank=True)
@@ -32,15 +32,15 @@ class Customer(Model):
         permission_classes = [CustomerPermissions]
 
     def __str__(self):
-        return self.name
+        return self.name or self.urlid
 
 
 class BusinessProvider(Model):
-    name = models.CharField(max_length=255)
-    fee = models.PositiveIntegerField(default='0')
+    name = models.CharField(max_length=255, null=True, blank=True)
+    fee = models.PositiveIntegerField(default='0', null=True, blank=True)
 
     def __str__(self):
-        return self.name
+        return self.name or self.urlid
 
 
 def auto_increment_project_number():
@@ -59,12 +59,12 @@ STATUS_CHOICES = [
 
 
 class Project(Model):
-    name = models.CharField(max_length=255)
+    name = models.CharField(max_length=255, null=True, blank=True)
     description = models.TextField(null=True, blank=True)
-    status = models.CharField(max_length=8, choices=STATUS_CHOICES, default='Private')
+    status = models.CharField(max_length=8, choices=STATUS_CHOICES, default='Private', null=True, blank=True)
     number = models.PositiveIntegerField(default=auto_increment_project_number, editable=False)
     creationDate = models.DateField(auto_now_add=True)
-    customer = models.ForeignKey(Customer, on_delete=models.DO_NOTHING)  # WARN add import
+    customer = models.ForeignKey(Customer, on_delete=models.DO_NOTHING, null=True, blank=True)
     team = models.ManyToManyField(settings.AUTH_USER_MODEL, through='Member', blank=True)
     captain = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.DO_NOTHING, blank=True, null=True,
                                 related_name='+')
@@ -82,15 +82,15 @@ class Project(Model):
         rdf_type = 'hd:project'
 
     def __str__(self):
-        return self.name
+        return self.name or self.urlid
 
     def get_admins(self):
         return self.members.filter(is_admin=True)
 
 
 class Member(Model):
-    project = models.ForeignKey(Project, on_delete=models.CASCADE, related_name='members')
-    user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE, related_name='projects')
+    project = models.ForeignKey(Project, on_delete=models.CASCADE, related_name='members', null=True, blank=True)
+    user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE, related_name='projects', null=True, blank=True)
     is_admin = models.BooleanField(default=False)
 
     class Meta(Model.Meta):
@@ -104,7 +104,7 @@ class Member(Model):
         view_set = ProjectMembersViewset
 
     def __str__(self):
-        return str(self.pk)
+        return str(self.pk) or self.urlid
 
     def save(self, *args, **kwargs):
         if self.user:
